 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 Reahl-commands contains useful command line commands for reahl components.
